@@ -5,15 +5,12 @@ use 5.008004;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-
-$VERSION = '0.04_01';
+our $VERSION = '0.05_01';
 
 use DateTime 0.1402;
 use DateTime::Calendar::Julian 0.04;
 
-use Carp;
-use Params::Validate qw/ validate SCALAR OBJECT /;
+use Carp ();
 
 use overload ( 'fallback' => 1,
                '<=>' => '_compare_overload',
@@ -22,119 +19,101 @@ use overload ( 'fallback' => 1,
                '+' => '_add_overload',
              );
 
-my %reform_dates;
-$reform_dates{$_->[0]} = DateTime->new( year  => $_->[1],
-                                        month => $_->[2],
-                                        day   => $_->[3] )
-    for [ italy      => 1582, 10, 15 ], # including some other catholic
-                                        # countries (spain, portugal, ...)
-        [ france     => 1582, 12, 20 ],
-        [ belgium    => 1583,  1,  1 ],
-        [ holland    => 1583,  1,  1 ], # or 1583-1-12?
-        [ liege      => 1583,  2, 21 ],
-        [ augsburg   => 1583,  2, 24 ],
-        [ treves     => 1583, 10, 15 ],
-        [ bavaria    => 1583, 10, 16 ],
-        [ tyrolia    => 1583, 10, 16 ],
-        [ julich     => 1583, 11, 13 ],
-        [ cologne    => 1583, 11, 14 ], # or 1583-11-13?
-        [ wurzburg   => 1583, 11, 15 ],
-        [ mainz      => 1583, 11, 22 ],
-        [ strasbourg_diocese => 1583, 11, 27 ],
-        [ baden      => 1583, 11, 27 ],
-        [ carynthia  => 1583, 12, 25 ],
-        [ bohemia    => 1584,  1, 17 ],
-        [ lucerne    => 1584,  1, 22 ],
-        [ silesia    => 1584,  1, 23 ],
-        [ westphalia => 1584,  7, 12 ],
-        [ paderborn  => 1585,  6, 27 ],
-        [ hungary    => 1587, 11,  1 ],
-        [ transylvania=>1590, 12, 25 ],
-        [ prussia    => 1610,  9,  2 ],
-        [ hildesheim => 1631,  3, 26 ],
-        [ minden     => 1668,  2, 12 ],
-        [ strasbourg => 1682,  2, 16 ],
-        [ denmark    => 1700,  3,  1 ],
-        [ germany_protestant => 1700,  3,  1 ],
-        [ gelderland => 1700,  7, 12 ],
-        [ faeror     => 1700, 11, 28 ], # or 1700-11-27?
-        [ iceland    => 1700, 11, 28 ],
-        [ utrecht    => 1700, 12, 12 ],
-        [ zurich     => 1701,  1, 12 ],
-        [ friesland  => 1701,  1, 12 ], # or 1701-01-13?
-        [ drente     => 1701,  5, 12 ], # or 1701-01-12?
-        [ uk         => 1752,  9, 14 ],
-        [ bulgaria   => 1915, 11, 14 ], # or 1916-04-14?
-        [ russia     => 1918,  2, 14 ],
-        [ latvia     => 1918,  2, 15 ],
-        [ romania    => 1919,  4, 14 ], # or 1924-10-14?
-        ;
-# Dates are from http://www.polysyllabic.com/GregConv.html and
-# http://privatewww.essex.ac.uk/~kent/calisto/guide/changes.htm
-# Only those dates that both sites agree on are included at the moment.
+use constant ARRAY_REF	=> ref [];
 
 {
-    my $DefaultReformDate;
-    sub DefaultReformDate
-    {
-        my $class = shift;
+    my %reform_dates = (
+	italy      => [ 1582, 10, 15 ], # including some other catholic
+					# countries (spain, portugal, ...)
+	france     => [ 1582, 12, 20 ],
+	belgium    => [ 1583,  1,  1 ],
+	holland    => [ 1583,  1,  1 ], # or 1583-1-12?
+	liege      => [ 1583,  2, 21 ],
+	augsburg   => [ 1583,  2, 24 ],
+	treves     => [ 1583, 10, 15 ],
+	bavaria    => [ 1583, 10, 16 ],
+	tyrolia    => [ 1583, 10, 16 ],
+	julich     => [ 1583, 11, 13 ],
+	cologne    => [ 1583, 11, 14 ], # or 1583-11-13?
+	wurzburg   => [ 1583, 11, 15 ],
+	mainz      => [ 1583, 11, 22 ],
+	strasbourg_diocese => [ 1583, 11, 27 ],
+	baden      => [ 1583, 11, 27 ],
+	carynthia  => [ 1583, 12, 25 ],
+	bohemia    => [ 1584,  1, 17 ],
+	lucerne    => [ 1584,  1, 22 ],
+	silesia    => [ 1584,  1, 23 ],
+	westphalia => [ 1584,  7, 12 ],
+	paderborn  => [ 1585,  6, 27 ],
+	hungary    => [ 1587, 11,  1 ],
+	transylvania => [ 1590, 12, 25 ],
+	prussia    => [ 1610,  9,  2 ],
+	hildesheim => [ 1631,  3, 26 ],
+	minden     => [ 1668,  2, 12 ],
+	strasbourg => [ 1682,  2, 16 ],
+	denmark    => [ 1700,  3,  1 ],
+	germany_protestant => [ 1700,  3,  1 ],
+	gelderland => [ 1700,  7, 12 ],
+	faeror     => [ 1700, 11, 28 ], # or 1700-11-27?
+	iceland    => [ 1700, 11, 28 ],
+	utrecht    => [ 1700, 12, 12 ],
+	zurich     => [ 1701,  1, 12 ],
+	friesland  => [ 1701,  1, 12 ], # or 1701-01-13?
+	drente     => [ 1701,  5, 12 ], # or 1701-01-12?
+	uk         => [ 1752,  9, 14 ],
+	bulgaria   => [ 1915, 11, 14 ], # or 1916-04-14?
+	russia     => [ 1918,  2, 14 ],
+	latvia     => [ 1918,  2, 15 ],
+	romania    => [ 1919,  4, 14 ], # or 1924-10-14?
+    );
 
-        if (@_)
-        {
-            $DefaultReformDate = shift;
-            unless (ref $DefaultReformDate) {
-                my $area = lc $DefaultReformDate;
-                $DefaultReformDate = $reform_dates{$area}
-                    or croak "Unknown calendar '$area'";
-            }
-        }
+    # Dates are from http://www.polysyllabic.com/GregConv.html and
+    # http://privatewww.essex.ac.uk/~kent/calisto/guide/changes.htm
+    # Only those dates that both sites agree on are included at the moment.
 
-        return $DefaultReformDate;
-    }
-}
-__PACKAGE__->DefaultReformDate('Italy');
-
-sub _init_reform_date {
-    my ($base, $self, $rd) = @_;
-
-    if ($rd && ref $rd) {
-        $self->{reform_date} = DateTime->from_object( object => $rd );
-    } elsif ($rd) {
-        $self->{reform_date} = $reform_dates{ lc $rd }
-            or croak "Unknown calendar region '$rd'";
-    } elsif (ref $base && $base->isa('DateTime::Calendar::Christian')) {
-        $self->{reform_date} = $base->{reform_date}
-    } else {
-        $self->{reform_date} = $base->DefaultReformDate;
+    # ALL interpretation of the reform_date argument MUST go through here.
+    sub _process_reform_date {
+	my ( $class, $rd ) = @_;
+	if ( my $ref = ref $rd ) {
+	    if ( ARRAY_REF eq $ref ) {
+		return DateTime->new(
+		    year	=> $rd->[0],
+		    month	=> $rd->[1] || 1,
+		    day	=> $rd->[2] || 1,
+		    hour	=> $rd->[3] || 0,
+		    minute	=> $rd->[4] || 0,
+		    second	=> $rd->[5] || 0,
+		    nanosecond	=> $rd->[6] || 0,
+		);
+	    } else {
+		return DateTime->from_object( object => $rd );
+	    }
+	} elsif ( $rd ) {
+	    if ( my $rda = $reform_dates{ my $rd_lc = lc $rd } ) {
+		ARRAY_REF eq ref $rda
+		    and return ( $reform_dates{$rd_lc} =
+		    $class->_process_reform_date( $rda ) );
+		return $rda;
+	    }
+	    if ( $rd =~ m/ \A [0-9] /smx
+		    and my @rda = split qr{ [^0-9]+ }smx, $rd ) {
+		return $class->_process_reform_date( \@rda );
+	    }
+	    Carp::croak( "Unknown calendar region '$rd'" );
+	} elsif ( ref $class && ( ref $class )->can( 'reform_date' ) ) {
+	    return $class->reform_date();
+	} else {
+	    return $class->DefaultReformDate();
+	}
     }
 }
 
+__PACKAGE__->DefaultReformDate( 'Italy' );
 
 sub new {
-    my $class = shift;
-    my %args = validate( @_,
-                         { year   => { type => SCALAR, default => undef },
-                           month  => { type => SCALAR, default => 1 },
-                           day    => { type => SCALAR, default => 1 },
-                           hour   => { type => SCALAR, default => 0 },
-                           minute => { type => SCALAR, default => 0 },
-                           second => { type => SCALAR, default => 0 },
-                           nanosecond => { type => SCALAR, default => 0 },
-                           locale  => { type => SCALAR | OBJECT,
-                                          default => $class->DefaultLocale },
-                           time_zone => { type => SCALAR | OBJECT,
-                                          default => 'floating' },
-                           reform_date => { type => SCALAR | OBJECT,
-                                            default => undef },
-                         }
-                       );
+    my ( $class, %args ) = @_;
 
-    my $self = {};
-
-    $class->_init_reform_date( $self, delete $args{reform_date} );
-
-    $class = ref $class if ref $class;
-    bless $self, $class;
+    my $self = $class->_new( \%args );
 
     if (defined $args{year}) {
         $self->{date} = DateTime::Calendar::Julian->new(%args);
@@ -147,6 +126,22 @@ sub new {
     return $self;
 }
 
+sub _new {
+    my ( $class, $arg, $method ) = @_;
+
+    my $self = bless {
+	reform_date	=> $class->_process_reform_date(
+	    delete $arg->{reform_date} ),
+    }, ref $class || $class;
+
+    if ( $method ) {
+	$self->{date} = DateTime->$method( %{ $arg } );
+	$self->_adjust_calendar();
+    }
+
+    return $self;
+}
+
 sub _adjust_calendar {
     my $self = shift;
 
@@ -156,6 +151,8 @@ sub _adjust_calendar {
     } elsif ($self->is_julian and $self->{date} >= $self->{reform_date}) {
         $self->{date} = DateTime->from_object( object => $self->{date} );
     }
+
+    return;
 }
 
 sub is_julian {
@@ -166,41 +163,51 @@ sub is_gregorian {
     return ! $_[0]->is_julian;
 }
 
-sub from_epoch {
-    my $class = shift;
-    my %args = @_;
-
-    my $self = {};
-
-    $class->_init_reform_date( $self, delete $args{reform_date} );
-
-    $class = ref $class if ref $class;
-    bless $self, $class;
-
-    $self->{date} = DateTime->from_epoch(%args);
-    $self->_adjust_calendar;
-
-    return $self;
+sub calendar_name {
+    my ( $self ) = @_;
+    return $self->is_julian() ? 'Julian' : 'Gregorian';
 }
 
-sub now { shift->from_epoch( epoch => (scalar time), @_ ) }
+sub from_epoch {
+    my ( $class, %args ) = @_;
+
+    return $class->_new( \%args, 'from_epoch' );
+}
+
+sub now { return shift->from_epoch( epoch => (scalar time), @_ ) }
  
-sub today { shift->now(@_)->truncate( to => 'day' ) }
+sub today { return shift->now(@_)->truncate( to => 'day' ) }
 
 sub from_object {
-    my $class = shift;
-    my %args = @_;
+    my ( $class, %args ) = @_;
 
-    my $self = {};
+    return $class->_new( \%args, 'from_object' );
+}
 
-    $class->_init_reform_date( $self, delete $args{reform_date} );
+sub from_day_of_year {
+    my ( $class, %args ) = @_;
 
-    $class = ref $class if ref $class;
-    bless $self, $class;
+    my $self = $class->_new( \%args );
 
-    my $object = $args{object};
-    $self->{date} = DateTime->from_object( object => $object );
-    $self->_adjust_calendar;
+    my $rd = $self->reform_date();
+    my $ry = $rd->year;
+
+    if ( $args{year} > $ry ) {
+	$self->{date} = DateTime->from_day_of_year( %args );
+    } elsif ( $args{year} < $ry ) {
+	$self->{date} = DateTime::Calendar::Julian->from_day_of_year(
+	    %args );
+    } else {
+	my $dev = DateTime::Calendar::Christian->gregorian_deviation( $rd );
+	my $rdoy = $rd->day_of_year - $dev;
+	if ( $args{day_of_year} < $rdoy ) {
+	    $self->{date} = DateTime::Calendar::Julian->from_day_of_year(
+		%args );
+	} else {
+	    $args{day_of_year} += $dev;
+	    $self->{date} = DateTime->from_day_of_year( %args );
+	}
+    }
 
     return $self;
 }
@@ -210,7 +217,6 @@ sub from_object {
 # 27.
 sub last_day_of_month {
     my ($class, %p) = @_;
-    my $month = $p{month};
     # First, determine the first day of the next month.
     $p{day} = 1;
     $p{month}++;
@@ -240,7 +246,7 @@ sub clone {
     my $new = {};
     $new->{reform_date} = $self->{reform_date}->clone;
     $new->{date} = $self->{date}->clone if exists $self->{date};
-    bless $new, ref $self;
+    return bless $new, ref $self;
 }
 
 sub is_leap_year {
@@ -291,7 +297,7 @@ sub _subtract_overload {
     }
 }
 
-sub add { shift->add_duration( DateTime::Duration->new(@_) ) }
+sub add { return shift->add_duration( DateTime::Duration->new(@_) ) }
 
 sub subtract { return shift->subtract_duration( DateTime::Duration->new(@_) ) }
 
@@ -334,6 +340,8 @@ sub add_duration {
     }
 
     $self->{date}->subtract( days => $dd ) if $dd;
+
+    return $self;
 }
 
 sub gregorian_deviation {
@@ -345,7 +353,7 @@ sub gregorian_deviation {
     return $date->gregorian_deviation;
 }
 
-sub reform_date { $_[0]->{reform_date} }
+sub reform_date { return $_[0]->{reform_date} }
 
 # Almost the same as DateTime::week
 sub week
@@ -402,11 +410,14 @@ sub _weeks_in_year
 }
 
 sub set {
-    my $self = shift;
+    my ( $self, %p ) = @_;
 
-    my %p = @_;
-    croak "Cannot change reform_date with set()"
+    Carp::croak( 'Cannot change reform_date with set()' )
         if exists $p{reform_date};
+    Carp::carp( 'You passed a locale to the set() method.',
+	' You should use set_locale() instead, as using set() may ',
+	'alter the local time near a DST boundary.' )
+	if $p{locale};
 
     my %old_p = 
         ( reform_date => $self->{reform_date},
@@ -423,10 +434,10 @@ sub set {
 }
 
 sub set_time_zone {
-    my $self = shift;
-
-    $self->{date}->set_time_zone(@_);
+    my ( $self, @arg ) = @_;
+    $self->{date}->set_time_zone( @arg );
     $self->_adjust_calendar;
+    return $self;
 }
 
 # This code assumes there is a month of December of the previous year.
@@ -448,47 +459,137 @@ sub day_of_year_0 {
     return shift->day_of_year - 1;
 }
 
-# Delegate to $self->{date}
+sub strftime {
+    my ( $self, @fmts ) = @_;
+    foreach ( @fmts ) {
+	s/ %\{ ( calendar_name ) \} / $self->_strftime_helper( "$1" ) /smxge;
+    }
+    return $self->{date}->strftime( @fmts );
+}
 
-for my $sub (qw/year ce_year month month_0 month_name month_abbr
+sub _strftime_helper {
+    my ( $self, $method ) = @_;
+    my $rslt = $self->$method();
+    $rslt =~ s/ % /%%/smxg;
+    return $rslt;
+}
+
+sub STORABLE_freeze {
+    my ( $self ) = @_;
+    return (
+	$self->reform_date,
+	$self->{date} ? $self->{date} : (),
+    );
+}
+
+sub STORABLE_thaw {
+    my ( $self, undef, $reform, $date ) = @_;
+    $self->{reform_date} = $reform;
+    defined $date
+	and $self->{date} = $date;
+    return $self;
+}
+
+
+# Delegate to $self->{date}
+for my $sub (
+		# The following by Eugene van der Pijll
+		qw/year ce_year month month_0 month_name month_abbr
                 day_of_month day_of_month_0 day_of_week day_of_week_0
                 day_name day_abbr ymd mdy dmy hour minute second hms
                 nanosecond millisecond microsecond
                 iso8601 datetime week_year week_number
                 time_zone offset is_dst time_zone_short_name locale
                 utc_rd_values utc_rd_as_seconds local_rd_as_seconds jd
-                mjd strftime epoch utc_year compare _compare_overload/,
-             # these should be replaced with a corrected version
-             qw/truncate/) {
+                mjd epoch utc_year compare /,
+		# these should be replaced with a corrected version -- EvdP
+		qw/truncate/,
+		# The following by Thomas R. Wyant, III
+		qw/
+		am_or_pm compare_ignore_floating
+		christian_era secular_era era era_abbr era_name
+		delta_days delta_md delta_ms duration_class format_cldr
+		formatter fractional_second hires_epoch
+		hour_1 hour_12 hour_12_0 is_finite is_infinite
+		leap_seconds local_day_of_week local_rd_values
+		quarter quarter_0 quarter_name quarter_abbr
+		set_locale set_formatter subtract_datetime_absolute
+		time_zone_long_name
+		year_with_christian_era year_with_era
+		year_with_secular_era
+		/,
+		# Because Eugene accepted week_number and week_year even
+		# though they might span the reform date, I will accept
+		# the following -- TRW
+		qw/
+		week_of_month
+		weekday_of_month
+		/,
+) {
     no strict 'refs';
     *$sub = sub {
                 my $self = shift;
-                croak "Empty date object in call to $sub"
+		Carp::croak( "Empty date object in call to $sub" )
                     unless exists $self->{date};
                 $self->{date}->$sub(@_)
             };
 }
 
-*mon = \&month;
-*mon_0 = \&month_0;
-*day  = \&day_of_month;
-*mday = \&day_of_month;
-*day_0  = \&day_of_month_0;
-*mday_0 = \&day_of_month_0;
-*wday = \&day_of_week;
-*dow  = \&day_of_week;
-*wday_0 = \&day_of_week_0;
-*dow_0  = \&day_of_week_0;
-*doy = \&day_of_year;
-*doy_0 = \&day_of_year_0;
-*date = \&ymd;
-*min = \&minute;
-*sec = \&second;
-*DateTime::Calendar::Christian::time = \&hms;
+sub _compare_overload {
+    my ( $self, $other ) = @_;
+    $self->{date}
+	or return -1;
+    return $self->{date}->_compare_overload( $other );
+}
+
+# Delegate to set();
+
+for my $name ( qw/ year month day hour minute second nanosecond / ) {
+    my $sub = "set_$name";
+    no strict 'refs';
+    *$sub = sub {
+	my ( $self, $value ) = @_;
+	return $self->set( $name => $value );
+    };	
+}
+
+{
+    no warnings 'once';
+
+    *mon = \&month;
+    *mon_0 = \&month_0;
+    *day  = \&day_of_month;
+    *mday = \&day_of_month;
+    *day_0  = \&day_of_month_0;
+    *mday_0 = \&day_of_month_0;
+    *wday = \&day_of_week;
+    *dow  = \&day_of_week;
+    *wday_0 = \&day_of_week_0;
+    *dow_0  = \&day_of_week_0;
+    *doq    = \&day_of_quarter;
+    *doq_0  = \&day_of_quarter_0;
+    *doy = \&day_of_year;
+    *doy_0 = \&day_of_year_0;
+    *date = \&ymd;
+    *min = \&minute;
+    *sec = \&second;
+    *DateTime::Calendar::Christian::time = \&hms;
+}
 
 sub DefaultLocale {
     shift;
-    DateTime->DefaultLocale(@_);
+    return DateTime->DefaultLocale( @_ );
+}
+
+{
+    my $DefaultReformDate;
+
+    sub DefaultReformDate {
+	my ( $class, $rd ) = @_;
+	$rd
+	    and $DefaultReformDate = $class->_process_reform_date( $rd );
+	return $DefaultReformDate;
+    }
 }
 
 1;
@@ -518,7 +619,7 @@ See L<DateTime> for information about most of the methods.
 
 The Julian calendar, introduced in Roman times, had an average year
 length of 365.25 days, about 0.03 days more than the correct number. When
-this difference had cummulated to about ten days, the calendar was
+this difference had accumulated to about ten days, the calendar was
 reformed by pope Gregory XIII, who introduced a new leap year rule. To
 correct for the error that had built up over the centuries, ten days
 were skipped in October 1582. In most countries, the change date was
@@ -528,20 +629,27 @@ change over until 1918.
 =head1 METHODS
 
 This manpage only describes those methods that differ from those of
-DateTime. See L<DateTime> for all other methods.
+DateTime. See L<DateTime|DateTime> for all other methods. A spirited
+attempt has been made to implement the B<entire> L<DateTime|DateTime>
+interface.
 
-=over 4
+Methods not documented below may behave in unexpected ways when they
+involve dates both before and after the reform date. For example,
+C<week_number()>, when called on a date in the reform year but after the
+reform, returns the week number in the Gregorian year, not the actual
+year.
+
+B<Caveat programmer.>
+
+=over
 
 =item * new( ... )
 
 Besides the usual parameters ("year", "month", "day", "hour", "minute",
-"second", "nanosecond", "fractional_seconds", "locale" and "time_zone"),
-this class method takes the
-additional "reform_date" parameter. This parameter can be a DateTime
-object (or an object that can be converted into a DateTime). This
-denotes the first date of the Gregorian calendar. It can also be a
-string, containing the name of a location, e.g. 'Italy'. Location names
-are not case-sensitive.
+"second", "nanosecond", "locale", "formatter" and "time_zone"),
+this class method takes the additional "reform_date" parameter. See
+L<SPECIFYING REFORM DATE|/SPECIFYING REFORM DATE> below for how to
+specify this.
 
 If this method is used as an instance method and no "reform_date" is
 given, the "reform_date" of the returned object is the same as the one
@@ -570,7 +678,106 @@ corresponding Julian date. This behaviour may change in future
 versions. If a date is given that can be both Julian and Gregorian, it
 will be considered Julian. This is a bug.
 
-The supported reform date location names are:
+=item * from_epoch, from_object, from_day_of_year, last_day_of_month
+
+These methods accept an additional "reform_date" argument. Note that the
+epoch is defined for most (all?) systems as a date in the Gregorian
+calendar.
+
+=item * reform_date
+
+Returns the date of the calendar reform, as a DateTime object.
+
+=item * is_julian, is_gregorian
+
+Return true or false indicating whether the datetime object is in a
+specific calendar.
+
+=item * calendar_name
+
+Return C<'Julian'> or C<'Gregorian'>, depending on the value returned by
+C<is_julian()>.
+
+=item * is_leap_year
+
+This method returns a true or false indicating whether or not the
+datetime object is in a leap year. If the object is in the year of the
+date reform, this method indicates whether there is a leap day in that
+year, irrespective of whether the datetime object is in the same
+calendar as the possible leap day.
+
+=item * days_in_year
+
+Returns the number of days in the year. Is equal to 365 or 366, except
+for the year(s) of the calendar reform.
+
+=item * day_of_year, day_of_year_0
+
+Returns the day of the year, either one-based or zero-based depending on
+the actual method called. In the reform year this is the actual number
+of days from January 1 (Julian) to the current date, whether Julian or
+Gregorian.
+
+=item * add_datetime, subtract_datetime
+
+These are done in terms of duration, so that, for example, subtracting a
+day from the reform date (Gregorian) gets you the day before the reform
+date (Julian).
+
+=item * strftime
+
+This override allows selected methods of this class (i.e. not inherited
+from DateTime) to be used in the C<'%{method_name}'> construction in
+templates. The only method allowed at the moment is C<calendar_name>.
+
+=item * gregorian_deviation( [$datetime] )
+
+This method returns the difference in days between the Gregorian and the
+Julian calendar. If the parameter $datetime is given, it will be used to
+calculate the result; in this case this method can be used as a class
+method.
+
+=item * DefaultReformDate
+
+This static method returns a L<DateTime|DateTime> object representing
+the default reform date. If called with an argument, the argument
+becomes the new reform date, which is returned. The argument is either a
+L<DateTime|DateTime> object (or something that can be converted into
+one) or a reform date location name. See
+L<SPECIFYING REFORM DATE|/SPECIFYING REFORM DATE> below for what kind of
+arguments can be specified.
+
+=back
+
+=head1 INTERFACES
+
+This module implements the following interfaces:
+
+=over
+
+=item * Storable
+
+This module implements the Storable interface. All the donkey work is
+done by L<DateTIme|DateTime>.
+
+=item * Overloading
+
+Addition, subtraction, and both string and numeric comparison are
+overloaded. Objects with no date (that is, objects initialized as "date
+generators") collate before objects with a date.
+
+=back
+
+=head1 SPECIFYING REFORM DATE
+
+The reform date represents the first date the Gregorian calendar came
+into use. It can be specified a number of different ways:
+
+=over
+
+=item * A DateTime object, or an object that can be converted into one.
+
+=item * A location name (case-insensitive) from the following list:
 
  Italy -------------- 1582-10-15 # and some other Catholic countries
  France ------------- 1582-12-20
@@ -614,46 +821,26 @@ The supported reform date location names are:
  Latvia ------------- 1918-2-15
  Romania ------------ 1919-4-14  # or 1924-10-14?
 
-=item * from_epoch
+=item * An array reference.
 
-This method accepts an additional "reform_date" argument. Note that the
-epoch is defined for most (all?) systems as a date in the Gregorian
-calendar.
+The first seven elements of the array are year, month, day, hour,
+minute, second and nanosecond. Element C<[0]> is the only one that is
+required. Elements C<[1]> and C<[2]> default to C<1>, and the rest to
+C<0>.
 
-=item * reform_date
+=item * An ISO-8601-ish string.
 
-Returns the date of the calendar reform, as a DateTime object.
-
-=item * is_julian, is_gregorian
-
-Return true or false indicating whether the datetime object is in a
-specific calendar.
-
-=item * is_leap_year
-
-This method returns a true or false indicating whether or not the
-datetime object is in a leap year. If the object is in the year of the
-date reform, this method indicates whether there is a leap day in that
-year, irrespective of whether the datetime object is in the same
-calendar as the possible leap day.
-
-=item * days_in_year
-
-Returns the number of days in the year. Is equal to 365 or 366, except
-for the year(s) of the calendar reform.
-
-=item * gregorian_deviation( [$datetime] )
-
-This method returns the difference in days between the Gregorian and the
-Julian calendar. If the parameter $datetime is given, it will be used to
-calculate the result; in this case this method can be used as a class
-method.
+The string is split on non-numerics, and the reform date initialized
+from a reference to the resultant array, as described in the previous
+item. The string B<must> be the punctuated form; that is, C<'1752-9-14'>
+will work, but C<'17520914'> will not. There must not be a zone
+specification, and the year must not be signed.
 
 =back
 
 =head1 BUGS
 
-=over 4
+=over
 
 =item * There are problems with calendars switch to Gregorian before 200
 AD or after about 4000 AD. Before 200 AD, this switch leads to
@@ -686,7 +873,7 @@ Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.  This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
-Copyright (C) 2016 Thomas R. Wyamt, III
+Copyright (C) 2016 Thomas R. Wyant, III
 
 =head1 SEE ALSO
 
@@ -695,3 +882,5 @@ L<DateTime>, L<DateTime::Calendar::Julian>
 datetime@perl.org mailing list
 
 =cut
+
+# ex: set textwidth=72 :
